==> 0.0.10.tar.gz: lib/src/models/user_model.dart <==
import 'dart:convert';

class UserModel {
  UserModel({
    required this.id,
    this.employeeID,
    required this.name,
    this.position,
    this.rank,
    required this.avatar,
    required this.email,
    this.companyID,
    this.companyName,
    this.divisionGroupID,
    this.divisionGroupName,
    this.companyAvatar,
    this.token,
    this.customToken,
    this.isAdmin = false,
    this.isSuperAdmin = false,
    this.isDefault = false,
  });
  late final String id;
  late final String? employeeID;
  late final String name;
  late final String? position;
  late final String? rank;
  late final String? avatar;
  late final String email;
  late final String? companyID;
  late final String? companyName;
  late final String? companyAvatar;
  late final String? divisionGroupID;
  late final String? divisionGroupName;
  late final String? token;
  late final String? customToken;
  late final bool isAdmin;
  late final bool isSuperAdmin;
  late final bool isDefault;

  UserModel.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    employeeID = json["employee_id"];
    name = json["name"];
    position = json["position"];
    rank = json["rank"];
    avatar = json["avatar"];
    email = json["email"];
    companyID = json["company_id"];
    companyName = json["company_name"];
    companyAvatar = json["company_avatar"];
    token = json["token"];
    customToken = json["custom_token"];
    isAdmin = json["is_admin"];
    isSuperAdmin = json["is_super_admin"];
    isDefault = json["is_default"];
    divisionGroupID = json["division_group_id"];
    divisionGroupName = json["division_group_id"];
  }

  UserModel copyWith({
    String? id,
    String? employeeID,
    String? name,
    String? position,
    String? rank,
    String? avatar,
    String? email,
    String? companyID,
    String? companyName,
    String? companyAvatar,
    String? token,
    String? customToken,
    bool? isAdmin,
    bool? isSuperAdmin,
    bool? isDefault,
    String? divisionGroupID,
    String? divisionGroupName,
  }) {
    return UserModel(
        id: id ?? this.id,
        employeeID: employeeID ?? this.employeeID,
        name: name ?? this.name,
        position: position ?? this.position,
        rank: rank ?? this.rank,
        avatar: avatar ?? this.avatar,
        email: email ?? this.email,
        companyID: companyID ?? this.companyID,
        companyName: companyName ?? this.companyName,
        companyAvatar: companyAvatar ?? this.companyAvatar,
        token: token ?? this.token,
        customToken: customToken ?? this.customToken,
        isAdmin: isAdmin ?? this.isAdmin,
        isSuperAdmin: isSuperAdmin ?? this.isSuperAdmin,
        isDefault: isDefault ?? this.isDefault,
        divisionGroupID: divisionGroupID ?? this.divisionGroupID,
        divisionGroupName: divisionGroupName ?? this.divisionGroupName);
  }

  Map<String, dynamic> toJson() {
    final _data = <String, dynamic>{};
    _data["id"] = id;
    _data["employee_id"] = employeeID;
    _data["name"] = name;
    _data["position"] = position;
    _data["rank"] = rank;
    _data["avatar"] = avatar;
    _data["email"] = email;
    _data["company_id"] = companyID;
    _data["company_name"] = companyName;
    _data["company_avatar"] = companyAvatar;
    _data["token"] = token;
    _data["custom_token"] = customToken;
    _data["is_admin"] = isAdmin;
    _data["is_super_admin"] = isSuperAdmin;
    _data["is_default"] = isDefault;
    _data["division_group_id"] = divisionGroupID;
    _data["division_group_id"] = divisionGroupName;
    return _data;
  }

  @override
  String toString() {
    final Map<String, dynamic> _data = toJson();
    return jsonEncode(_data);
  }
}

==> 0.0.50.tar.gz: lib/src/models/user_model.dart <==
import 'dart:convert';

import 'package:cloud_firestore/cloud_firestore.dart';

class UserModel {
  UserModel({
    required this.id,
    this.employeeID,
    required this.name,
    this.position,
    this.rank,
    required this.avatar,
    required this.email,
    this.companyID,
    this.companyName,
    this.divisionGroupID,
    this.divisionGroupName,
    this.companyAvatar,
    this.phone,
    this.updatedAt,
    this.createdAt,
    this.token,
    this.customToken,
    this.refreshToken,
    this.isAdmin = false,
    this.isSuperAdmin = false,
    this.isDefault = false,
  });
  late final String id;
  String? employeeID;
  late final String name;
  String? position;
  String? rank;
  String? avatar;
  late final String email;
  String? companyID;
  String? companyName;
  String? companyAvatar;
  String? divisionGroupID;
  String? divisionGroupName;
  String? token;
  String? refreshToken;
  String? customToken;
  DateTime? createdAt;
  DateTime? updatedAt;
  String? phone;
  late final bool isAdmin;
  late final bool isSuperAdmin;
  late final bool isDefault;

  UserModel.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    employeeID = json["employee_id"];
    name = json["name"];
    position = json["position"];
    phone = json["phone"];
    rank = json["rank"];
    avatar = json["avatar"];
    email = json["email"];
    companyID = json["company_id"];
    companyName = json["company_name"];
    companyAvatar = json["company_avatar"];
    token = json["token"];
    customToken = json["custom_token"];
    refreshToken = json["refresh_token"];
    isAdmin = json["is_admin"];
    isSuperAdmin = json["is_super_admin"];
    isDefault = json["is_default"];
    divisionGroupID = json["division_group_id"];
    divisionGroupName = json["division_group_name"];
    if (json['createdAt'] != null) createdAt = json['createdAt'].toDate();
    if (json['updatedAt'] != null) updatedAt = json['updatedAt'].toDate();
  }

  UserModel copyWith({
    String? id,
    String? employeeID,
    String? name,
    String? position,
    String? rank,
    String? avatar,
    String? email,
    String? companyID,
    String? companyName,
    String? companyAvatar,
    String? phone,
    String? token,
    String? customToken,
    String? refreshToken,
    bool? isAdmin,
    bool? isSuperAdmin,
    bool? isDefault,
    String? divisionGroupID,
    String? divisionGroupName,
    DateTime? createdAt,
    DateTime? updatedAt,
  }) {
    return UserModel(
        id: id ?? this.id,
        employeeID: employeeID ?? this.employeeID,
        name: name ?? this.name,
        position: position ?? this.position,
        rank: rank ?? this.rank,
        avatar: avatar ?? this.avatar,
        email: email ?? this.email,
        companyID: companyID ?? this.companyID,
        phone: phone ?? this.phone,
        companyName: companyName ?? this.companyName,
        companyAvatar: companyAvatar ?? this.companyAvatar,
        token: token ?? this.token,
        customToken: customToken ?? this.customToken,
        refreshToken: refreshToken ?? this.refreshToken,
        isAdmin: isAdmin ?? this.isAdmin,
        isSuperAdmin: isSuperAdmin ?? this.isSuperAdmin,
        isDefault: isDefault ?? this.isDefault,
        divisionGroupID: divisionGroupID ?? this.divisionGroupID,
        createdAt: createdAt ?? this.createdAt,
        updatedAt: updatedAt ?? this.updatedAt,
        divisionGroupName: divisionGroupName ?? this.divisionGroupName);
  }

  Map<String, dynamic> toJson() {
    final _data = <String, dynamic>{};
    _data["id"] = id;
    _data["employee_id"] = employeeID;
    _data["name"] = name;
    _data["position"] = position;
    _data["rank"] = rank;
    _data["avatar"] = avatar;
    _data["email"] = email;
    _data["company_id"] = companyID;
    _data["phone"] = phone;
    _data["company_name"] = companyName;
    _data["company_avatar"] = companyAvatar;
    _data["token"] = token;
    _data["custom_token"] = customToken;
    _data["refresh_token"] = refreshToken;
    _data["is_admin"] = isAdmin;
    _data["is_super_admin"] = isSuperAdmin;
    _data["is_default"] = isDefault;
    _data["division_group_id"] = divisionGroupID;
    _data["division_group_name"] = divisionGroupName;
    if (updatedAt != null) _data['updatedAt'] = Timestamp.fromDate(updatedAt!);
    if (createdAt != null) _data['createdAt'] = Timestamp.fromDate(createdAt!);

    return _data;
  }

  @override
  String toString() {
    final Map<String, dynamic> _data = toJson();
    return jsonEncode(_data);
  }
}
